<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.2                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2004 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: TestOfStatisticsCommon.php 1051 2004-11-29 17:33:23Z andrew $
*/

/**
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once maintenancePath . '/maintenance-common.php';
require_once maintenancePath . '/libraries/max/Dal.php';
require_once maintenancePath . '/libraries/max/Dal/TableCore.php';
require_once maintenancePath . '/libraries/max/Maintenance/Statistics.php';
require_once maintenancePath . '/libraries/pear/Date.php';
require_once maintenancePath . '/libraries/pear/Log.php';

/**
 * A class for testing the Maintenance_Statistics_Common class.
 */
class Maintenance_TestOfStatisticsCommon extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function Maintenance_TestOfStatisticsCommon()
    {        
        $this->UnitTestCase();
    }
    
    /**
     * Tests the constructor method. Uses the AdServer module
     * as a basis, but the test is equally valid for other modules,
     * as the mechanism by which the modules differ is tested in
     * the Dal package.
     */
    function testMaintenance_Statistics_Common()
    {
        debug('Running test', PEAR_LOG_DEBUG);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $tables =& Dal_Table_Core::singleton();
        $dal =& Dal::singleton();
        // Create the required tables
        $tables->createTable('data_raw_ad_impression');
        $tables->createTable('log_maintenance_statistics');
        // Create a Maintenance_Statistics_Common object with no data,
        // and an operation interval less than 60
        $conf['maintenance']['operation_interval'] = 30;
        Maintenance_Statistics::instance('AdServer', $msObj);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Create a Maintenance_Statistics_Common object with no data,
        // and an operation interval greater than 60
        $conf['maintenance']['operation_interval'] = 120;
        Maintenance_Statistics::instance('AdServer', $msObj);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        /*----------------------------------------------------------*/
        /* Run tests relating to a 30 minute operation interval     */
        /*----------------------------------------------------------*/
        $conf['maintenance']['operation_interval'] = 30;
        // Insert ad impression data 5 minutes ago, in current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:05:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 20 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:50:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 20 minutes ago, in current hour
        // and current operation interval
        $now = new Date('2004-06-06 18:25:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:05:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 20 minutes ago, in current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:45:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:25:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 39 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:31:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 39 minutes ago, in current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:01:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 61 minutes ago, in previous hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:39:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        /*----------------------------------------------------------*/
        /* Run tests relating to a 120 minute operation interval    */
        /*----------------------------------------------------------*/
        $conf['maintenance']['operation_interval'] = 120;
        // Insert ad impression data 5 minutes ago, in current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:05:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 20 minutes ago, in previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:10:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:50:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 20 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:50:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 20 minutes ago, in current hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:20:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 61 minutes ago, in previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:40:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:39:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 61 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:39:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        // Insert ad impression data 121 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 16:39:00')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        /*----------------------------------------------------------*/
        /* Run tests relating to a 30 minute operation interval     */
        /*----------------------------------------------------------*/
        $conf['maintenance']['operation_interval'] = 30;
        // Insert OI stats run 5 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 0, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 5 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 0, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 20 minutes ago, up to  previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:50:00', 0, '2004-06-06 17:29:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 20 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:50:00', 1, '2004-06-06 16:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 20 minutes ago, up to current hour
        // and current operation interval
        $now = new Date('2004-06-06 18:25:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 0, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 20 minutes ago, up to current hour
        // and current operation interval
        $now = new Date('2004-06-06 18:25:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 1, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 20 minutes ago, up to current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:45:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:25:00', 0, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 20 minutes ago, up to current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:45:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:25:00', 1, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run data 39 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:31:00', 0, '2004-06-06 17:29:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run data 39 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:31:00', 1, '2004-06-06 16:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 39 minutes ago, up to current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:01:00', 0, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 39 minutes ago, up to current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:01:00', 1, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 61 minutes ago, up to previous hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:39:00', 0, '2004-06-06 17:29:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 61 minutes ago, in previous hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:39:00', 1, '2004-06-06 16:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        /*----------------------------------------------------------*/
        /* Run tests relating to a 120 minute operation interval    */
        /*----------------------------------------------------------*/
        $conf['maintenance']['operation_interval'] = 120;
        // Insert OI stats run 5 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 0, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 5 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 1, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 20 minutes ago, up to previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:50:00', 0, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 20 minutes ago, up to previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:50:00', 1, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 20 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:50:00', 0, '2004-06-06 15:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 20 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:50:00', 1, '2004-06-06 16:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 20 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:20:00', 0, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 20 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:20:00', 1, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 61 minutes ago, up to previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:39:00', 0, '17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 61 minutes ago, up to previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:39:00', 1, '2004-06-06 17:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 61 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:39:00', 0, '2004-06-06 15:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 61 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:39:00', 1, '2004-06-06 16:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert OI stats run 121 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 16:39:00', 0, '2004-06-06 15:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Insert hourly stats run 121 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 16:39:00', 1, '2004-06-06 15:59:59')";
        $dal->execute($query, $result);
        // Test
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['log_maintenance_statistics']}";
        $dal->execute($query, $result);
        // Drop the tables
        $tables->dropTable($conf['table']['data_raw_ad_impression']);
        $tables->dropTable($conf['table']['log_maintenance_statistics']);
    }
    
    /**
     * Tests the deleteOldData() method. Uses the AdServer module
     * as a basis, but the test is equally valid for other modules,
     * as the mechanism by which the modules differ is tested in
     * the Dal package.
     */
    function testDeleteOldData()
    {
        debug('Running test', PEAR_LOG_DEBUG);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['maintenance']['operation_interval'] = 60;
        $conf['table']['split'] = false;
        $tables =& Dal_Table_Core::singleton();
        $dal =& Dal::singleton();
        // Create the required tables
        $tables->createTable('campaigns_trackers');
        $tables->createTable('data_raw_ad_click');
        $tables->createTable('data_raw_ad_impression');
        $tables->createTable('data_raw_ad_request');
        $tables->createTable('log_maintenance_statistics');
        // Create a Maintenance_Statistics_Common object
        Maintenance_Statistics::instance('AdServer', $msObj);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Maintenance/data/TestOfStatisticsCommon.php';
        // Insert the test data
        $dal->execute(DELETE_OLD_DATA_CAMPAIGNS_TRACKERS, $result);
        $dal->execute(DELETE_OLD_DATA_AD_CLICKS, $result);
        $dal->execute(DELETE_OLD_DATA_AD_IMPRESSIONS, $result);
        $dal->execute(DELETE_OLD_DATA_AD_REQUESTS, $result);
        // Set compact_stats to false
        $conf['maintenance']['compact_stats'] = false;
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Set compact_stats to true
        $conf['maintenance']['compact_stats'] = true;
        // Set compact_stats grace to one hour
        $conf['maintenance']['compact_stats_grace'] = 3600;
        // Disable the tracker
        $conf['modules']['Tracker'] = false;
        // Set the Maintenance_Statistics_Common object to not have updated
        $msObj->updateHourly = false;
        $msObj->updateOI = false;
        $msObj->updateUsingOI = false;
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Set the Maintenance_Statistics_Common object to have updated by the hour,
        // but not to have updated using the OI
        $msObj->updateHourly = true;
        $msObj->updateOI = false;
        $msObj->updateUsingOI = false;
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Set the Maintenance_Statistics_Common object to have updated by the
        // operation interval, but to have updated using the OI
        $msObj->updateHourly = false;
        $msObj->updateOI = true;
        $msObj->updateUsingOI = true;
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Set the Maintenance_Statistics_Common object to have updated by the hour,
        // and to have updated using the OI, with an upToDateHourly date
        $msObj->updateHourly = true;
        $msObj->updateOI = false;
        $msObj->updateUsingOI = true;
        $msObj->upToDateHourly = new Date('2004-06-06 17:59:59');
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 3);
        // Drop and re-create the tables
        $tables->dropTable($conf['table']['data_raw_ad_click']);
        $tables->dropTable($conf['table']['data_raw_ad_impression']);
        $tables->dropTable($conf['table']['data_raw_ad_request']);
        $tables->dropTable($conf['table']['log_maintenance_statistics']);
        $tables->createTable('data_raw_ad_click');
        $tables->createTable('data_raw_ad_impression');
        $tables->createTable('data_raw_ad_request');
        $tables->createTable('log_maintenance_statistics');
        // Re-insert the test data
        $dal->execute(DELETE_OLD_DATA_AD_CLICKS, $result);
        $dal->execute(DELETE_OLD_DATA_AD_IMPRESSIONS, $result);
        $dal->execute(DELETE_OLD_DATA_AD_REQUESTS, $result);
        // Set the Maintenance_Statistics_Common object to have updated by the
        // operation internval, and to have NOT updated using the OI, with an upToDateOI date
        $msObj->updateHourly = false;
        $msObj->updateOI = true;
        $msObj->updateUsingOI = false;
        $msObj->upToDateOI = new Date('2004-06-06 17:59:59');
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 3);
        // Drop the tables
        $tables->dropTable($conf['table']['campaigns_trackers']);
        $tables->dropTable($conf['table']['data_raw_ad_click']);
        $tables->dropTable($conf['table']['data_raw_ad_impression']);
        $tables->dropTable($conf['table']['data_raw_ad_request']);
        $tables->dropTable($conf['table']['log_maintenance_statistics']);
    }
    
    /**
     * Tests the logCompletion() method. Uses the AdServer module
     * as a basis, but the test is equally valid for other modules,
     * as the mechanism by which the modules differ is tested in
     * the Dal package.
     */
    function testLogCompletion()
    {
        debug('Running test', PEAR_LOG_DEBUG);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $tables =& Dal_Table_Core::singleton();
        $dal =& Dal::singleton();
        // Create the required table
        $tables->createTable('data_raw_ad_impression');
        $tables->createTable('log_maintenance_statistics');
        $tables->createTable('userlog');
        // Create a Maintenance_Statistics_AdServer object
        $now = new Date('2004-06-06 18:10:00');
        Maintenance_Statistics::instance('AdServer', $msObj, $now);
        // Set some of the object's variables, and log
        $msObj->updateOI = true;
        $msObj->upToDateOI = new Date('2004-06-06 17:59:59');
        $msObj->updateHourly = false;
        $msObj->upToDateHourly = null;
        $end = new Date('2004-06-06 18:12:00');
        $msObj->logCompletion($end);
        // Test
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 0";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['start_run'], '2004-06-06 18:10:00');
        $this->assertEqual($row['end_run'], '2004-06-06 18:12:00');
        $this->assertEqual($row['duration'], 120);
        $this->assertEqual($row['updated_to'], '2004-06-06 17:59:59');
        // Set some of the object's variables, and log
        $msObj->updateOI = false;
        $msObj->upToDateOI = null;
        $msObj->updateHourly = true;
        $msObj->upToDateHourly = new Date('2004-06-06 17:59:59');
        $end = new Date('2004-06-06 18:13:00');
        $msObj->logCompletion($end);
        // Test
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 1";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['start_run'], '2004-06-06 18:10:00');
        $this->assertEqual($row['end_run'], '2004-06-06 18:13:00');
        $this->assertEqual($row['duration'], 180);
        $this->assertEqual($row['updated_to'], '2004-06-06 17:59:59');
        // Set some of the object's variables, and log
        $msObj->updateOI = true;
        $msObj->upToDateOI = new Date('2004-06-06 17:59:59');
        $msObj->updateHourly = true;
        $msObj->upToDateHourly = new Date('2004-06-06 17:59:59');
        $end = new Date('2004-06-06 18:14:00');
        $msObj->logCompletion($end);
        // Test
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 2";
        $dal->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['start_run'], '2004-06-06 18:10:00');
        $this->assertEqual($row['end_run'], '2004-06-06 18:14:00');
        $this->assertEqual($row['duration'], 240);
        $this->assertEqual($row['updated_to'], '2004-06-06 17:59:59');
        // Drop the table
        $tables->dropTable($conf['table']['data_raw_ad_impression']);
        $tables->dropTable($conf['table']['log_maintenance_statistics']);
        $tables->dropTable($conf['table']['userlog']);
    }
    
}

?>